@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 ### after: use lib qw(@RT_LIB_PATH@);
-use lib qw(/Users/sunnavy/bps/git/rt/local/lib /Users/sunnavy/bps/git/rt/lib);
+use lib qw(/home/brad/BPS/work/rts/rt6-plugin-testing/local/lib /home/brad/BPS/work/rts/rt6-plugin-testing/lib);
 
 package RT::Extension::Announce::Test;
 
